Changelog
=========

1.0.3 (2023-01-28)
~~~~~~~~~~~~~~~~~~

- Cut length of name+function columns for mysql users (fixes #1)

1.0.2 (2023-01-28)
~~~~~~~~~~~~~~~~~~

- Added missing `@scheduled_task`
- Fixed iommi admin config
- Fixed bug where very rarely the last log message wasn't properly forwarded to the run view (it was still logged to the DB though)


1.0.1 (2023-01-28)
~~~~~~~~~~~~~~~~~~

- Fixed README on pypi


1.0.0 (2023-01-28)
~~~~~~~~~~~~~~~~~~

- Initial release
